Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(459)

Unified Diff: Source/core/html/shadow/SpinButtonElement.cpp

Issue 977113003: Rename renderer() to layoutObject(). (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/html/shadow/SpinButtonElement.cpp
diff --git a/Source/core/html/shadow/SpinButtonElement.cpp b/Source/core/html/shadow/SpinButtonElement.cpp
index d2f642730338da2dd4109bd9c75f67f8eddcbfea..bef4fb6883043a6cd69e8e8178d60d1f1317c46b 100644
--- a/Source/core/html/shadow/SpinButtonElement.cpp
+++ b/Source/core/html/shadow/SpinButtonElement.cpp
@@ -93,11 +93,11 @@ void SpinButtonElement::defaultEventHandler(Event* event)
if (box->pixelSnappedBorderBoxRect().contains(local)) {
// The following functions of HTMLInputElement may run JavaScript
// code which detaches this shadow node. We need to take a reference
// and check renderer() after such function calls.
RefPtrWillBeRawPtr<Node> protector(this);
if (m_spinButtonOwner)
m_spinButtonOwner->focusAndSelectSpinButtonOwner();
- if (renderer()) {
+ if (layoutObject()) {
if (m_upDownState != Indeterminate) {
// A JavaScript event handler called in doStepAction() below
// might change the element state and we might need to
@@ -125,7 +125,7 @@ void SpinButtonElement::defaultEventHandler(Event* event)
UpDownState oldUpDownState = m_upDownState;
m_upDownState = (local.y() < box->size().height() / 2) ? Up : Down;
if (m_upDownState != oldUpDownState)
- renderer()->setShouldDoFullPaintInvalidation();
+ layoutObject()->setShouldDoFullPaintInvalidation();
} else {
releaseCapture();
m_upDownState = Indeterminate;
@@ -93,11 +93,11 @@ void SpinButtonElement::defaultEventHandler(Event* event)
// The following functions of HTMLInputElement may run JavaScript
// code which detaches this shadow node. We need to take a reference
- // and check renderer() after such function calls.
+ // and check layoutObject() after such function calls.
RefPtrWillBeRawPtr<Node> protector(this);
if (m_spinButtonOwner)
« no previous file with comments | « Source/core/html/shadow/SliderThumbElement.cpp ('k') | Source/core/html/shadow/TextControlInnerElements.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698